pub struct ViewRefFocused;Expand description
The type corresponding to the ViewRefFocused protocol. A method of enabling a ViewRef creator to determine if its ViewRef has gained or lost focus in the view tree.
The protocol client has implicit access to the ViewRef it created; the protocol itself does not accept a ViewRef parameter. Clients, both trusted or otherwise, need access to view-focus state, so the protocol is deliberately minimal. Possession of a ViewRef (and this protocol) does not grant the power to learn about a ViewRef’s focus state.